@@ -15,22 +15,26 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
-"""This module contains a sqoop 1 operator"""
+"""This module contains a sqoop 1 operator."""
+from __future__ import annotations
+
 import os
 import signal
-from typing import Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.apache.sqoop.hooks.sqoop import SqoopHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class SqoopOperator(BaseOperator):
     """
     Execute a Sqoop job.
-    Documentation for Apache Sqoop can be found here:
-    https://sqoop.apache.org/docs/1.4.2/SqoopUserGuide.html
+
+    Documentation for Apache Sqoop can be found here: https://sqoop.apache.org/docs/1.4.2/SqoopUserGuide.html
 
     :param conn_id: str
     :param cmd_type: str specify command to execute "export" or "import"
@@ -72,79 +76,77 @@ class SqoopOperator(BaseOperator):
     :param create_hcatalog_table: Have sqoop create the hcatalog table passed
         in or not
     :param properties: additional JVM properties passed to sqoop
-    :param extra_import_options: Extra import options to pass as dict.
-        If a key doesn't have a value, just pass an empty string to it.
-        Don't include prefix of -- for sqoop options.
-    :param extra_export_options: Extra export options to pass as dict.
+    :param extra_options:  Extra import/export options to pass as dict to the SqoopHook.
         If a key doesn't have a value, just pass an empty string to it.
         Don't include prefix of -- for sqoop options.
+    :param libjars: Optional Comma separated jar files to include in the classpath.
     """
 
-    template_fields = (
-        'conn_id',
-        'cmd_type',
-        'table',
-        'query',
-        'target_dir',
-        'file_type',
-        'columns',
-        'split_by',
-        'where',
-        'export_dir',
-        'input_null_string',
-        'input_null_non_string',
-        'staging_table',
-        'enclosed_by',
-        'escaped_by',
-        'input_fields_terminated_by',
-        'input_lines_terminated_by',
-        'input_optionally_enclosed_by',
-        'properties',
-        'extra_import_options',
-        'driver',
-        'extra_export_options',
-        'hcatalog_database',
-        'hcatalog_table',
-        'schema',
+    template_fields: Sequence[str] = (
+        "conn_id",
+        "cmd_type",
+        "table",
+        "query",
+        "target_dir",
+        "file_type",
+        "columns",
+        "split_by",
+        "where",
+        "export_dir",
+        "input_null_string",
+        "input_null_non_string",
+        "staging_table",
+        "enclosed_by",
+        "escaped_by",
+        "input_fields_terminated_by",
+        "input_lines_terminated_by",
+        "input_optionally_enclosed_by",
+        "properties",
+        "extra_options",
+        "driver",
+        "hcatalog_database",
+        "hcatalog_table",
+        "schema",
     )
-    ui_color = '#7D8CA4'
+    template_fields_renderers = {"query": "sql"}
+    ui_color = "#7D8CA4"
 
     def __init__(
         self,
         *,
-        conn_id: str = 'sqoop_default',
-        cmd_type: str = 'import',
-        table: Optional[str] = None,
-        query: Optional[str] = None,
-        target_dir: Optional[str] = None,
+        conn_id: str = "sqoop_default",
+        cmd_type: str = "import",
+        table: str | None = None,
+        query: str | None = None,
+        target_dir: str | None = None,
         append: bool = False,
-        file_type: str = 'text',
-        columns: Optional[str] = None,
-        num_mappers: Optional[int] = None,
-        split_by: Optional[str] = None,
-        where: Optional[str] = None,
-        export_dir: Optional[str] = None,
-        input_null_string: Optional[str] = None,
-        input_null_non_string: Optional[str] = None,
-        staging_table: Optional[str] = None,
+        file_type: str = "text",
+        columns: str | None = None,
+        num_mappers: int | None = None,
+        split_by: str | None = None,
+        where: str | None = None,
+        export_dir: str | None = None,
+        input_null_string: str | None = None,
+        input_null_non_string: str | None = None,
+        staging_table: str | None = None,
         clear_staging_table: bool = False,
-        enclosed_by: Optional[str] = None,
-        escaped_by: Optional[str] = None,
-        input_fields_terminated_by: Optional[str] = None,
-        input_lines_terminated_by: Optional[str] = None,
-        input_optionally_enclosed_by: Optional[str] = None,
+        enclosed_by: str | None = None,
+        escaped_by: str | None = None,
+        input_fields_terminated_by: str | None = None,
+        input_lines_terminated_by: str | None = None,
+        input_optionally_enclosed_by: str | None = None,
         batch: bool = False,
         direct: bool = False,
-        driver: Optional[Any] = None,
+        driver: Any | None = None,
         verbose: bool = False,
         relaxed_isolation: bool = False,
-        properties: Optional[Dict[str, Any]] = None,
-        hcatalog_database: Optional[str] = None,
-        hcatalog_table: Optional[str] = None,
+        properties: dict[str, Any] | None = None,
+        hcatalog_database: str | None = None,
+        hcatalog_table: str | None = None,
         create_hcatalog_table: bool = False,
-        extra_import_options: Optional[Dict[str, Any]] = None,
-        extra_export_options: Optional[Dict[str, Any]] = None,
-        schema: Optional[str] = None,
+        extra_options: dict[str, Any] | None = None,
+        schema: str | None = None,
+        libjars: str | None = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
@@ -178,17 +180,17 @@ class SqoopOperator(BaseOperator):
         self.hcatalog_table = hcatalog_table
         self.create_hcatalog_table = create_hcatalog_table
         self.properties = properties
-        self.extra_import_options = extra_import_options or {}
-        self.extra_export_options = extra_export_options or {}
-        self.hook: Optional[SqoopHook] = None
+        self.extra_options = extra_options or {}
+        self.hook: SqoopHook | None = None
         self.schema = schema
+        self.libjars = libjars
 
-    def execute(self, context: Dict[str, Any]) -> None:
-        """Execute sqoop job"""
+    def execute(self, context: Context) -> None:
+        """Execute sqoop job."""
         if self.hook is None:
             self.hook = self._get_hook()
 
-        if self.cmd_type == 'export':
+        if self.cmd_type == "export":
             self.hook.export_table(
                 table=self.table,  # type: ignore
                 export_dir=self.export_dir,
@@ -203,18 +205,11 @@ class SqoopOperator(BaseOperator):
                 input_optionally_enclosed_by=self.input_optionally_enclosed_by,
                 batch=self.batch,
                 relaxed_isolation=self.relaxed_isolation,
-                extra_export_options=self.extra_export_options,
                 schema=self.schema,
             )
-        elif self.cmd_type == 'import':
-            # add create hcatalog table to extra import options if option passed
-            # if new params are added to constructor can pass them in here
-            # so don't modify sqoop_hook for each param
-            if self.create_hcatalog_table:
-                self.extra_import_options['create-hcatalog-table'] = ''
-
+        elif self.cmd_type == "import":
             if self.table and self.query:
-                raise AirflowException('Cannot specify query and table together. Need to specify either or.')
+                raise AirflowException("Cannot specify query and table together. Need to specify either or.")
 
             if self.table:
                 self.hook.import_table(
@@ -227,7 +222,6 @@ class SqoopOperator(BaseOperator):
                     where=self.where,
                     direct=self.direct,
                     driver=self.driver,
-                    extra_import_options=self.extra_import_options,
                     schema=self.schema,
                 )
             elif self.query:
@@ -239,7 +233,6 @@ class SqoopOperator(BaseOperator):
                     split_by=self.split_by,
                     direct=self.direct,
                     driver=self.driver,
-                    extra_import_options=self.extra_import_options,
                 )
             else:
                 raise AirflowException("Provide query or table parameter to import using Sqoop")
@@ -249,10 +242,16 @@ class SqoopOperator(BaseOperator):
     def on_kill(self) -> None:
         if self.hook is None:
             self.hook = self._get_hook()
-        self.log.info('Sending SIGTERM signal to bash process group')
-        os.killpg(os.getpgid(self.hook.sub_process.pid), signal.SIGTERM)
+        self.log.info("Sending SIGTERM signal to bash process group")
+        os.killpg(os.getpgid(self.hook.sub_process_pid), signal.SIGTERM)
 
     def _get_hook(self) -> SqoopHook:
+        """Returns a SqoopHook instance."""
+        # Add `create-hcatalog-table` to extra options if option passed to operator in case of `import`
+        # command. Similarly, if new parameters are added to the operator, you can pass them to
+        # `extra_options` so that you don't need to modify `SqoopHook` for each new parameter.
+        if self.cmd_type == "import" and self.create_hcatalog_table:
+            self.extra_options["create-hcatalog-table"] = ""
         return SqoopHook(
             conn_id=self.conn_id,
             verbose=self.verbose,
@@ -260,4 +259,6 @@ class SqoopOperator(BaseOperator):
             hcatalog_database=self.hcatalog_database,
             hcatalog_table=self.hcatalog_table,
             properties=self.properties,
+            libjars=self.libjars,
+            extra_options=self.extra_options,
         )
